@@ -1,4 +1,4 @@
-/* api.h	Header file for GSS-API.
+/* api.h --- Header file for GSS-API.
  * Copyright (C) 2003, 2004  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with GSS; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -55,22 +55,11 @@
 #ifndef GSSAPI_H_
 #define GSSAPI_H_
 
-
-
 /*
  * First, include stddef.h to get size_t defined.
  */
 #include <stddef.h>
 
-
-#ifdef GSS_SHOULD_INCLUDE_XOM
-/*
- * If the platform supports the xom.h header file, it should be
- * included here.
- */
-#include <xom.h>
-#endif
-
 /*
  * Now define the three implementation-dependent types.
  */
@@ -92,21 +81,8 @@ typedef unsigned int gss_uint32;
 typedef unsigned long gss_uint32;
 #endif
 
-#ifdef OM_STRING
 /*
- * We have included the xom.h header file.  Verify that OM_uint32
- * is defined correctly.
- */
-
-#if sizeof(gss_uint32) != sizeof(OM_uint32)
-#error Incompatible definition of OM_uint32 from xom.h
-#endif
-
-typedef OM_object_identifier gss_OID_desc, *gss_OID;
-
-#else
-/*
- * We can't use X/Open definitions, so roll our own.
+ * We don't use X/Open definitions, so roll our own.
  */
 
 typedef gss_uint32 OM_uint32;
@@ -117,8 +93,6 @@ typedef struct gss_OID_desc_struct
   void *elements;
 } gss_OID_desc, *gss_OID;
 
-#endif
-
 typedef struct gss_OID_set_desc_struct
 {
   size_t count;
@@ -150,11 +124,6 @@ typedef int gss_cred_usage_t;
 /*
  * Flag bits for context-level services.
  */
-
-
-
-
-
 #define GSS_C_DELEG_FLAG      1
 #define GSS_C_MUTUAL_FLAG     2
 #define GSS_C_REPLAY_FLAG     4
