@@ -1,5 +1,5 @@
 /* ext.c --- Implementation of GSS specific extensions.
- * Copyright (C) 2003, 2004  Simon Josefsson
+ * Copyright (C) 2003, 2004, 2005  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
  *
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with GSS; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -31,7 +31,7 @@
 void (*gss_alloc_fail_function) (void) = 0;
 
 void
-xalloc_die (void)
+gss_xalloc_die (void)
 {
   if (gss_alloc_fail_function)
     (*gss_alloc_fail_function) ();
@@ -152,41 +152,6 @@ gss_duplicate_oid (OM_uint32 * minor_status,
   return GSS_S_COMPLETE;
 }
 
-/**
- * gss_release_oid:
- * @minor_status: (Integer, modify) Mechanism specific status code.
- * @oid: (gss_OID, modify) The OID to be deleted.
- *
- * Free GSSAPI-allocated storage associated with an OID.  The OID is
- * set to GSS_C_NO_OID on successful completion of this call.
- *
- * WARNING: This function is a GNU GSS specific extension, and is not
- * part of the official GSS API.
- *
- * Return value:
- *
- * `GSS_S_COMPLETE`: Successful completion.
- **/
-OM_uint32
-gss_release_oid (OM_uint32 * minor_status, gss_OID * oid)
-{
-  if (minor_status)
-    *minor_status = 0;
-
-  if (!oid)
-    return GSS_S_FAILURE | GSS_S_CALL_INACCESSIBLE_READ;
-
-  if (*oid != GSS_C_NO_OID)
-    {
-      if ((*oid)->elements)
-	free ((*oid)->elements);
-      free (*oid);
-      *oid = GSS_C_NO_OID;
-    }
-
-  return GSS_S_COMPLETE;
-}
-
 /**
  * gss_userok:
  * @name: (gss_name_t, read) Name to be compared.
