@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with GSS; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -25,6 +25,9 @@
 /* Get size_t. */
 #include <stddef.h>
 
+/* If non-NULL, call this function when memory is exhausted. */
+extern void (*gss_alloc_fail_function) (void);
+
 /* See version.c. */
 extern const char *gss_check_version (const char *req_version);
 
@@ -36,8 +39,6 @@ gss_copy_oid (OM_uint32 * minor_status,
 extern OM_uint32
 gss_duplicate_oid (OM_uint32 * minor_status,
 		   const gss_OID src_oid, gss_OID * dest_oid);
-extern OM_uint32
-gss_release_oid (OM_uint32 * minor_status, gss_OID * oid);
 extern int gss_userok (const gss_name_t name, const char *username);
 
 /* See asn1.c. */
@@ -51,7 +52,7 @@ gss_encapsulate_token_prefix (const gss_buffer_t input_message,
 extern int
 gss_decapsulate_token (const gss_buffer_t input_message,
 		       const gss_OID token_oid,
-		       char **dataptr, size_t *datalen);
+		       char **dataptr, size_t * datalen);
 
 /* Static versions of the public OIDs for use, e.g., in static
    variable initalization.  See oid.c. */
